==> the-tmp-1.0.9.tgz: package/lib/TheTmp.js <==
/**
 * @class TheTmp
 */
'use strict'

const tmp = require('tmp')

/** @lends TheTmp */
class TheTmp {
  /**
   * Generate tmp file
   * @param {Object} [options={}] - Optional settings
   * @param {string} [options.prefix] - Prefix for generated
   * @returns {Promise<Object>}
   */
  async generate (options = {}) {
    return await new Promise((resolve, reject) => {
      tmp.file(options, (err, filename, descriptor, cleanup) => {
        if (err) {
          reject(err)
          return
        }
        resolve({ cleanup, descriptor, path: filename })
      })
    })
  }

  /**
   * Generate tmp directory
   * @param {Object} [options={}] - Optional settings
   * @param {string} [options.prefix] - Prefix for generated
   * @returns {Promise<Object>}
   */
  async generateDir (options = {}) {
    return await new Promise((resolve, reject) => {
      tmp.dir(options, (err, dirname, cleanup) => {
        if (err) {
          reject(err)
          return
        }
        resolve({ cleanup, path: dirname })
      })
    })
  }

  /**
   * Create and use tmp file until handler resolved (or rejected)
   * @param {function} handler - Handler function to use tmp file
   * @param {Object} options - Tmp options
   * @returns {Promise<void>}
   */
  async while (handler, options = {}) {
    const { cleanup, descriptor, path: filename } = await this.generate(options)
    try {
      await handler(filename, descriptor)
    } finally {
      cleanup()
    }
  }

  /**
   * Create an use tmp directory until handler resolved (or rejected)
   * @param {function} handler - Handler function to use tmp file
   * @param {Object} options - Tmp options
   * @returns {Promise<void>}
   */
  async whileDir (handler, options = {}) {
    const { cleanup, path: dirname } = await this.generateDir(options)
    try {
      await handler(dirname)
    } finally {
      cleanup()
    }
  }
}

module.exports = TheTmp

==> the-tmp-1.0.10.tgz: package/lib/TheTmp.js <==
/**
 * @class TheTmp
 */
'use strict'

const tmp = require('tmp')

/** @lends TheTmp */
class TheTmp {
  /**
   * Generate tmp file
   * @param {Object} [options={}] - Optional settings
   * @param {?string} [options.prefix] - Prefix for generated
   * @returns {Promise<Object>}
   */
  async generate (options = {}) {
    const { prefix } = options
    return await new Promise((resolve, reject) => {
      tmp.file({ prefix }, (err, filename, descriptor, cleanup) => {
        if (err) {
          reject(err)
          return
        }
        resolve({ cleanup, descriptor, path: filename })
      })
    })
  }

  /**
   * Generate tmp directory
   * @param {Object} [options={}] - Optional settings
   * @param {?string} [options.prefix] - Prefix for generated
   * @returns {Promise<Object>}
   */
  async generateDir (options = {}) {
    const { prefix } = options
    return await new Promise((resolve, reject) => {
      tmp.dir({
        prefix,
        unsafeCleanup: true,
      }, (err, dirname, cleanup) => {
        if (err) {
          reject(err)
          return
        }
        resolve({ cleanup, path: dirname })
      })
    })
  }

  /**
   * Create and use tmp file until handler resolved (or rejected)
   * @param {function} handler - Handler function to use tmp file
   * @param {Object} options - Tmp options
   * @returns {Promise<void>}
   */
  async while (handler, options = {}) {
    const { cleanup, descriptor, path: filename } = await this.generate(options)
    try {
      await handler(filename, descriptor)
    } finally {
      cleanup()
    }
  }

  /**
   * Create an use tmp directory until handler resolved (or rejected)
   * @param {function} handler - Handler function to use tmp file
   * @param {Object} options - Tmp options
   * @returns {Promise<void>}
   */
  async whileDir (handler, options = {}) {
    const { cleanup, path: dirname } = await this.generateDir(options)
    try {
      await handler(dirname)
    } finally {
      cleanup()
    }
  }
}

module.exports = TheTmp
